@@ -2,10 +2,9 @@
 #   MARSSmcinit function
 #   Does a simple MonteCarlo initialization of the EM routine
 #######################################################################################################
-
 MARSSmcinit = function(MLEobj) {
 
-  drawProgressBar = FALSE #If the time library is not installed, no prog bar
+  drawProgressBar = FALSE 
   if(!MLEobj$control$silent) { #then we can draw a progress bar
     cat("\n"); cat("> Starting Monte Carlo Initializations\n")
     prev = progressBar()
@@ -13,19 +12,19 @@ MARSSmcinit = function(MLEobj) {
   }
 
   y = MLEobj$model$data
-  ## M matrix for handling missing values
-  M = MLEobj$model$M
-  #Make sure the missing vals in y are zeroed out
-  for(i in 1:dim(y)[2]){ y[!as.logical(takediag(M[,,i])),i]=0 }
-
-  m = dim(MLEobj$model$fixed$Z)[2]
+  miss.value = MLEobj$model$miss.value
+  m = dim(MLEobj$model$fixed$x0)[1]
   n = dim(y)[1]
   TT = dim(y)[2]
+  ## YM matrix for handling missing values
+  if(is.na(miss.value)){ YM=matrix(as.numeric(!is.na(y)),n,TT)
+  }else  YM=matrix(as.numeric(!(y==miss.value)),n,TT) 
+  #Make sure the missing vals in y are zeroed out
+  y[YM==0]=0
+
   free.tmp = MLEobj$model$free 
-  dim.tmp = list(Z=c(n,m), A=c(n,1), R=c(n,n), B=c(m,m), U=c(m,1), Q=c(m,m))
-  # since boundsInits names are different
-  tmp = MLEobj$control$boundsInits
-  bounds.tmp = list(B=tmp$B, U=tmp$U, Q=tmp$Q, Z=tmp$Z, A=tmp$A, R=tmp$R)
+  dim.tmp = list(Z=c(n,m), A=c(n,1), R=c(n,n), B=c(m,m), U=c(m,1), Q=c(m,m), x0=c(m,1))
+  bounds.tmp = MLEobj$control$MCbounds
   init = bestinits = MLEobj$start
   bestLL = -1.0e10
 
@@ -34,47 +33,45 @@ MARSSmcinit = function(MLEobj) {
     init.loop = init
       
     # Draw random values
-    en = c("Z", "A", "R", "B", "U", "Q")
+    en = c("Z", "A", "R", "B", "U", "Q","x0")
     for(el in en) {
-      if(FALSE %in% is.na(free.tmp[[el]])){
-        dim.param = dim.tmp[[el]]
+      dim.param = dim.tmp[[el]]
+      if(!is.fixed(free.tmp[[el]])){
         bounds.param = bounds.tmp[[el]]
-        tmp=as.design(MLEobj$model$fixed[[el]],MLEobj$model$free[[el]])
+        #use the first fixed and free in a temporally varying model; arbitrary
+        tmp=list(f=sub3D(MLEobj$model$fixed[[el]],t=1),D=sub3D(MLEobj$model$free[[el]],t=1))
         if(el %in% c("Q", "R")){   # random starts drawn from a wishart dist
 	        if( bounds.param[1] < dim.param[1]){ df=dim.param[1] }else{ df=bounds.param[1] }
 	        S=diag(bounds.param[2],dim.param[1])
 	        #draw a random matrix from wishart
 	        tmp.random = rwishart(df, S)/df
 	        #reapply the sharing and fixed constraints 
-          element.random = solve(t(tmp$D)%*%tmp$D)%*%t(tmp$D)%*%(vec(tmp.random)-tmp$f)
-          param.random = unvec(tmp$f + tmp$D%*%element.random, dim.param)
+          par.random = solve(t(tmp$D)%*%tmp$D)%*%t(tmp$D)%*%(vec(tmp.random)-tmp$f)
 	      }else{
-	        element.random = matrix(runif(dim(tmp$D)[2], bounds.param[1], bounds.param[2]), dim(tmp$D)[2],1)
-          param.random = unvec(tmp$f+tmp$D%*%element.random, dim.param)
+	        par.random = matrix(runif(dim(tmp$D)[2], bounds.param[1], bounds.param[2]), dim(tmp$D)[2],1)
           if(el %in% c("B")){
-           tmp.max=max(abs(eigen(param.random,only.values=TRUE)$values))
+           tmp.max=max(abs(eigen(par.random,only.values=TRUE)$values))
            #rescale to bring the max abs eigenvalues to between 0 and 1
-           param.random = unvec(tmp$f+tmp$D%*%( element.random/(tmp.max/runif(1,.01,.99)) ), dim.param)
+           par.random =  par.random/(tmp.max/runif(1,.01,.99))
+          }
+          if(el %in% c("x0")){
+           x0init = MLEobj$start$x0
+           x.lo = ifelse(x0init > 0, exp(bounds.param[1])*x0init, exp(bounds.param[2])*x0init)
+           x.hi = ifelse(x0init > 0, exp(bounds.param[2])*x0init, exp(bounds.param[1])*x0init)
+           par.random = matrix(runif(dim(tmp$D)[2], x.lo, x.hi), dim(tmp$D)[2],1)
           }
-        } 
-      }else{ param.random=MLEobj$model$fixed[[el]] }
-      init.loop[[el]] = param.random 
-    }
 
-    ## x0
-    x0init = MLEobj$start$x0
-    x.lo = ifelse(x0init > 0, 0.75*x0init, 1.25*x0init)
-    x.hi = ifelse(x0init > 0, 1.25*x0init, 0.75*x0init)
-    fix.tmp = MLEobj$model$fixed$x0
-    fix.tmp[is.na(fix.tmp)] = 0 
-    init.loop$x0 = fix.tmp + array(runif(m, x.lo, x.hi), dim=c(m,1))    
+        } 
+      }else{ par.random=matrix(0,0,1) }
+      init.loop[[el]] = par.random 
+    }
 
     ## Call MARSSkem() with these inits 
     MLEobj$start = init.loop
     MLEobj$control$maxit = MLEobj$control$numInitSteps
     MLEobj$control$minit = 1
     MLEobj$control$silent = TRUE #don't print convergence information during kem call          
-    MLEobj = MARSSkem(MLEobj)    
+    MLEobj = MARSSkem(MLEobj)  #get new fit using this init  
 
     if(drawProgressBar==TRUE) prev = progressBar(loop/MLEobj$control$numInits, prev)
 
@@ -82,20 +79,11 @@ MARSSmcinit = function(MLEobj) {
 ## Revise: Only use bootstrap param draws where loglike did not go down during numInitSteps
     if(MLEobj$logLik > bestLL) {
       # update the best initial parameter estimates
-      tmp = MLEobj$par
-      bestinits$Z = tmp$Z
-      bestinits$A = tmp$A
-      bestinits$R = tmp$R
-      bestinits$B = tmp$B
-      bestinits$U = tmp$U
-      bestinits$Q = tmp$Q
-      bestinits$x0 = tmp$x0
-      bestinits$V0 = tmp$V0
+      bestinits = MLEobj$par
       bestLL = MLEobj$logLik
     }
    
   } # end numInits loop
 
   return(bestinits)
-
 }
